@@ -32,7 +32,7 @@ VALUE rb_tamu_anova_alloc(int argc, VALUE *argv, VALUE klass)
 VALUE rb_tamu_anova_printtable(VALUE *vTable)
 {
   struct tamu_anova_table *table;
-  Data_Get_Struct(vTable, struct tamu_anova_table, table);
+  Data_Get_Struct(*vTable, struct tamu_anova_table, table);
   tamu_anova_printtable(*table);
   return Qtrue;
 }
